.. PynamiX documentation master file, created by
   sphinx-quickstart on Thu Nov 14 12:08:09 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PanDEM's documentation!
===================================

`pandem` is a python package for converting between discrete element output formats. It contains the following modules:

.. toctree::

   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
